@@ -110,7 +110,7 @@ public class ClassFile implements Cloneable {
    * @param interfaces array of interfaces this class implements
    * @param fields fields this class will have
    */
-  public ClassFile(int modifiers,String name,Class superClass,
+  public ClassFile(int modifiers,String name,Class<?> superClass,
                    Class[] interfaces,LocalField[] fields) {
     
     constPoolData=new ByteArrayOutputStream();
@@ -452,7 +452,7 @@ public class ClassFile implements Cloneable {
           int defClassID=specialMds[i][0] % 100;
           definingClass=specialClasses[defClassID];
           name=specialMdsN[specialMds[i][1]];
-          params=new Class[specialMds[i].length-2];
+          params=new Class<?>[specialMds[i].length-2];
           for(int j=0;j<params.length;j++) {
             params[j]=specialClasses[specialMds[i][2+j]];
           };
@@ -508,7 +508,7 @@ public class ClassFile implements Cloneable {
       // method or constructor
       boolean inInterface=false;
       int cfID=10;
-      Class dClass;
+      Class<?> dClass;
       if (m instanceof Constructor) {
         code(0xb7);                        //         |  invokespecial
         cfID++;
@@ -959,7 +959,7 @@ public class ClassFile implements Cloneable {
         case 11: // Constructor
         case 12: // Field
           Member member = (Member) item;
-          Class dClass=member.getDeclaringClass();
+          Class<?> dClass=member.getDeclaringClass();
           int entryType;
           if (Library.isField(member))
             entryType=9;  //          CONSTANT_Fieldref = 9;
@@ -998,7 +998,7 @@ public class ClassFile implements Cloneable {
                              member.getName());
     int sign_ind=getUTFIndex(Library.getSignature(member));
 
-    Class dClass=member.getDeclaringClass();
+    Class<?> dClass=member.getDeclaringClass();
     int cls_ind;
     if (dClass==null) cls_ind=2;  else  cls_ind=getIndex(dClass,9); 
     //  this class ---^^^^^^^^^                  9 means Class--^
