@@ -134,7 +134,7 @@ public abstract class CompiledExpression {
    * this method provides is that a variable of the returned expression type
    * can be assigned by a reference, resulting from a call to evaluate.
    */
-  public abstract Class getTypeC();
+  public abstract Class<?> getTypeC();
   
   /**
    * Evaluates the expression, representing result as an object.
