@@ -62,7 +62,7 @@ public class TableWriter {
           "java.lang.Long",                             // 25 0x19
           "java.lang.Float",                            // 26 0x1A
           "java.lang.Double",                           // 27 0x1B
-          "gnu.jel.reflect.String"                      // 29 0x1C
+          "gnu.jel.reflect.String"                      // 28 0x1C
         };
         tables.put("specialTypes",specialTypesStr);
 
@@ -170,6 +170,14 @@ public class TableWriter {
           {27,10},             // java.lang.Double.doubleValue()       | 26
           {11,11,30},          // String.valueOf(Object)               | 27 // unwraps String-like
           {31,12,11,11},       // CompiledExpression.compare(String,String) | 28 // compares two strings
+          {20+100,0,0},        // java.lang.Boolean(boolean)           | 29
+          {21+100,0,1},        // java.lang.Byte(byte)                 | 30
+          {22+100,0,2},        // java.lang.Character(char)            | 31
+          {23+100,0,3},        // java.lang.Short(short)               | 32
+          {24+100,0,4},        // java.lang.Integer(int)               | 33
+          {25+100,0,5},        // java.lang.Long(long)                 | 34
+          {26+100,0,6},        // java.lang.Float(float)               | 35
+          {27+100,0,7},        // java.lang.Double(double)             | 36
         };
         tables.put("specialMds",specialMds);
 
