@@ -45,9 +45,9 @@ public class ClassFileExprTest extends TestCase {
     lf[0]=new LocalField(0x0002,(new Object[0]).getClass(),"e",null);
     //	cf = new ClassFile(0x0001,"dump",(new Object()).getClass(),null,lf);
     
-    Class[] stat=new Class[1];
+    Class[] stat=new Class<?>[1];
     stat[0]=Class.forName("java.lang.Math");
-    Class[] dyn=new Class[1];
+    Class[] dyn=new Class<?>[1];
     dyn[0]=Class.forName("java.lang.Double");
     lib=new Library(stat,dyn,null,null,null);
     
@@ -61,11 +61,11 @@ public class ClassFileExprTest extends TestCase {
     retID_patchback=0;
 
     // prepare eval methods
-    Class[] paramsE=new Class[1];
+    Class[] paramsE=new Class<?>[1];
     paramsE[0]=(new Object[0]).getClass();
     for(int i=0;i<numPrimitives-1;i++) {
       String name="evaluate";
-      Class cls=OP.specialTypes[i];
+      Class<?> cls=OP.specialTypes[i];
       if (i!=8) 
         name=name+'_'+cls;
       else 
@@ -74,7 +74,7 @@ public class ClassFileExprTest extends TestCase {
     };
 
     // hand-compile a class template
-    Class cmplExpr=Class.forName("gnu.jel.CompiledExpression");
+    Class<?> cmplExpr=Class.forName("gnu.jel.CompiledExpression");
     cf=new ClassFile(0x0001,"dump",cmplExpr,null,lf);
     // public 
     LocalMethod cnstr=
@@ -82,7 +82,7 @@ public class ClassFileExprTest extends TestCase {
     cf.newMethod(cnstr,null);
     cf.code(0x2a);                //| aload_0  ;loads "this"
     cf.noteStk(-1,11); // not important what, it must be a reference
-    Constructor supInit=cmplExpr.getConstructor(new Class[0]);
+    Constructor<?> supInit=cmplExpr.getConstructor(new Class<?>[0]);
     cf.code(0xb7);                //| invokespecial
     cf.writeShort(cf.getIndex(supInit,11));  //|    super();
     cf.noteStk(11,-1);
@@ -98,7 +98,7 @@ public class ClassFileExprTest extends TestCase {
     cf.code(0xAC);                //| ireturn
     cf.noteStk(4,-1); // rm   "int"
 
-    cf_orig=(ClassFile)cf.clone();
+    cf_orig=cf.clone();
 
     cf.newMethod(eval_methods[8],null);
     cf.code(0x01);                //| aconst_null
@@ -292,9 +292,9 @@ public class ClassFileExprTest extends TestCase {
 
     //    this.setName(testTitle.toString());
 
-    Stack paramOPs=new Stack();
+    Stack<OP> paramOPs=new Stack<OP>();
     IntegerStack paramsStart=new IntegerStack();
-    Stack oldLists=new Stack();
+    // Stack oldLists=new Stack();
     IntegerStack branchStack=new IntegerStack();
       
     OP cop;
@@ -444,7 +444,7 @@ public class ClassFileExprTest extends TestCase {
               };
                   
               Object otl=null;
-              Class otlc=null;
+              Class<?> otlc=null;
                 
               if (makeFloat) {
                 otl=new Float(value.floatValue());
@@ -479,7 +479,7 @@ public class ClassFileExprTest extends TestCase {
               };
 
               Object otl=null;
-              Class otlc=null;
+              Class<?> otlc=null;
               if (!makelong) { // Check ranges
                 if (value<=127) {
                   otl=new Byte((byte)value);
@@ -577,10 +577,10 @@ public class ClassFileExprTest extends TestCase {
               int ps=paramsStart.pop();
               int np=paramOPs.size()-ps;
 
-              Class[] params=new Class[np];
+              Class[] params=new Class<?>[np];
               OP[] paramsOPs=new OP[np];
               for(int i=np-1;i>=0;i--) {
-                paramsOPs[i]=(OP)paramOPs.pop();
+                paramsOPs[i]=paramOPs.pop();
                 params[i]=paramsOPs[i].resType;
               };
 
@@ -606,7 +606,7 @@ public class ClassFileExprTest extends TestCase {
               for(int i=0;i<np;i++) {
                 paramOPs.push(paramsOPs[i]);
               };
-              paramOPs.push(new OPcall(paramOPs,m,false));
+              paramOPs.push(new OPcall(m, np, paramOPs, false));
             };
           };
         };
@@ -614,14 +614,14 @@ public class ClassFileExprTest extends TestCase {
     };
       
     // remove TSB at return if present
-    if (((OP)paramOPs.peek()).resID==10) {
+    if ((paramOPs.peek()).resID==10) {
       paramOPs.push(new OPunary(paramOPs,11,null,false));
     };
 
-    OP rop=(OP)paramOPs.peek();
+    OP rop=paramOPs.peek();
     int retID=rop.resID>9?8:rop.resID; // compute base type (actually
     //                                    not needed since RET does it alr.)
-    Class retType=rop.resType;
+    Class<?> retType=rop.resType;
 
     // add the "return" instruction
     paramOPs.push(new OPunary(paramOPs,3)); 
@@ -629,7 +629,7 @@ public class ClassFileExprTest extends TestCase {
     if (paramOPs.size()!=1)
       System.err.println("Extra paramOPs left in stack when compiling.");
 
-    OP program=(OP) paramOPs.pop();
+    OP program=paramOPs.pop();
 
     // form name
     String name="evaluate";
@@ -641,7 +641,7 @@ public class ClassFileExprTest extends TestCase {
       if (verbose) System.out.print(toStr(program));
         
       // make class
-      ClassFile cf=(ClassFile)cf_orig.clone();
+      ClassFile cf=cf_orig.clone();
         
       // set return type
       int otsize=cf.tsize;
